PositionalRadixTree

Struct PositionalRadixTree 

pub struct PositionalRadixTree<V, K = PositionalSequenceHash>
where K: PositionalHash + Hash + Eq + Clone,
{ /* private fields */ }
Positionally sparse radix tree for efficient indexing of PositionalSequenceHashes.

Implementations

Source

impl<V, K> PositionalRadixTree<V, K>
where K: PositionalHash + Hash + Eq + Clone,

pub fn new() -> Self

Creates a new empty PositionalRadixTree.

pub fn prefix(&self, key: &K) -> RefMut<'_, u64, DashMap<K, V>>

Provides the entry for the key at the given position.

pub fn position(&self, position: u64) -> Option<RefMut<'_, u64, DashMap<K, V>>>

Provides the sub-map for all entries at the given position.

pub fn len(&self) -> usize

Returns the number of entries in the PositionalRadixTree.

pub fn is_empty(&self) -> bool

Returns true if the PositionalRadixTree is empty.