pub struct PositionalRadixTree<V, K = PositionalSequenceHash>{ /* private fields */ }Expand description
Positionally sparse radix tree for efficient indexing of PositionalSequenceHashes.
Implementations
Sourceimpl<V, K> PositionalRadixTree<V, K>
impl<V, K> PositionalRadixTree<V, K>
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new empty PositionalRadixTree.
Sourcepub fn prefix(&self, key: &K) -> RefMut<'_, u64, DashMap<K, V>>
pub fn prefix(&self, key: &K) -> RefMut<'_, u64, DashMap<K, V>>
Provides the entry for the key at the given position.
Sourcepub fn position(&self, position: u64) -> Option<RefMut<'_, u64, DashMap<K, V>>>
pub fn position(&self, position: u64) -> Option<RefMut<'_, u64, DashMap<K, V>>>
Provides the sub-map for all entries at the given position.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of entries in the PositionalRadixTree.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the PositionalRadixTree is empty.