pub struct TokenBlock { /* private fields */ }Expand description
Represents a completed, immutable block of tokens with associated hashes.
Contains exactly block_size tokens and includes the SaltHash, BlockHash,
SequenceHash, PositionalSequenceHash, PositionalLineageHash, and optionally the parent’s SequenceHash.
Implementations
Sourceimpl TokenBlock
impl TokenBlock
Sourcepub fn next_block(&self) -> PartialTokenBlock
pub fn next_block(&self) -> PartialTokenBlock
Creates a new PartialTokenBlock representing the block immediately following this one.
The new partial block will have the correct parent_sequence_hash and position set.
Sourcepub fn block_hash(&self) -> BlockHash
pub fn block_hash(&self) -> BlockHash
Returns the hash of only the tokens within this block.
Sourcepub fn sequence_hash(&self) -> SequenceHash
pub fn sequence_hash(&self) -> SequenceHash
Returns the sequence-aware hash for this block.
Sourcepub fn parent_sequence_hash(&self) -> Option<SequenceHash>
pub fn parent_sequence_hash(&self) -> Option<SequenceHash>
Returns the sequence hash of the preceding block, if any.
Sourcepub fn block_size(&self) -> usize
pub fn block_size(&self) -> usize
Returns the number of tokens in the block.
Sourcepub fn positional_sequence_hash(&self) -> PositionalSequenceHash
pub fn positional_sequence_hash(&self) -> PositionalSequenceHash
Returns the positional sequence hash for this block.
Sourcepub fn positional_lineage_hash(&self) -> PositionalLineageHash
pub fn positional_lineage_hash(&self) -> PositionalLineageHash
Returns the positional lineage hash for this block.